import asyncio
import warnings

import pytest

from bitcart import BTC
from bitcart.coin import Coin

TEST_XPUB = "xprv9yFGRF1GzMMydx5AK9FEU3UhqcHAmKZNSy8EvfBtztGvNtSfB1jLnkAJa4cvc33DJEpY5JXMDAdhN3fyanJJsNGcXSNsojKxzeX7EPEe8rg"


@pytest.yield_fixture(scope="session")
def event_loop(request):
    loop = asyncio.get_event_loop_policy().new_event_loop()
    yield loop
    loop.close()


@pytest.fixture(autouse=True, scope="session")
async def coin():
    return Coin()


@pytest.fixture(autouse=True, scope="session")
async def btc_nowallet():
    with warnings.catch_warnings():
        warnings.simplefilter("ignore")
        return BTC()


@pytest.fixture(autouse=True, scope="session")
async def btc():
    return BTC(xpub=TEST_XPUB)



"""Test that Coin class methods are abstract, and test module loading
coin fixture is the abstract coin class tested
"""
import pytest

pytestmark = pytest.mark.asyncio


async def test_help(coin):
    with pytest.raises(NotImplementedError):
        await coin.help()



"""Tests bitcoin methods implementation on mainnet, requires daemon to be running on localhost:5000

If this succeeds, most likely other coins will succeed too
"""
import pytest

pytestmark = pytest.mark.asyncio


async def test_help(btc):
    data = await btc.help()
    assert isinstance(data, list)
    assert len(data) > 0
    assert "broadcast" in data
    assert "gettransaction" in data
    assert "help" in data



import os

from setuptools import find_packages, setup

from sync_generator import main as generate

SYNC_REQS = ["jsonrpcclient[requests]"]
ASYNC_REQS = ["jsonrpcclient[aiohttp]", "aiohttp<4.0.0"]
SYNC_EXTRAS = {"webhook": ["flask"], "proxy": ["requests[socks]"]}
ASYNC_EXTRAS = {"proxy": ["aiohttp_socks"]}


def main() -> None:
    ASYNC = os.getenv("ASYNC", True) in ["true", "True", True]
    if not ASYNC:
        generate()

    setup(
        name="bitcart" if not ASYNC else "bitcart-async",
        packages=find_packages(),
        version="0.9.0",
        license="MIT",
        description="Bitcart coins support library",
        long_description=open("README.md").read(),
        long_description_content_type="text/markdown",
        author="MrNaif2018",
        author_email="chuff184@gmail.com",
        url="https://github.com/MrNaif2018/bitcart-sdk",
        keywords=["electrum", " daemon", "bitcart"],
        install_requires=SYNC_REQS if not ASYNC else ASYNC_REQS,
        extras_require=SYNC_EXTRAS if not ASYNC else ASYNC_EXTRAS,
        classifiers=[
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Developers",
            "Topic :: Software Development :: Build Tools",
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.6",
            "Programming Language :: Python :: 3.7",
            "Programming Language :: Python :: 3.8",
        ],
    )


if __name__ == "__main__":
    main()



from typing import Union

from .btc import BTC

ASYNC = False


class BCH(BTC):
    coin_name = "BCH"
    friendly_name = "Bitcoin Cash"
    RPC_URL = "http://localhost:5004"

    def history(self: "BCH") -> dict:
        return self.server.history()  # type: ignore

    def addrequest(
        self: "BCH",
        amount: Union[int, float],
        description: str = "",
        expire: Union[int, float] = 15,
    ) -> dict:
        expiration = 60 * expire if expire else None
        return self.server.addrequest(  # type: ignore
            amount=amount, memo=description, expiration=expiration, force=True
        )
